emw3162 driver

Fork of emw3162-driver-mbed-os-5 by Maggie Mei

Revision:
2:fb6251306b21
Parent:
1:3c8bed04849d
Child:
3:a6f80a95b039
--- a/EMW3162Interface.h	Fri Nov 04 02:14:19 2016 +0000
+++ b/EMW3162Interface.h	Mon Nov 14 02:30:49 2016 +0000
@@ -1,4 +1,4 @@
 /* ESP8266 implementation of NetworkInterfaceAPI
  * Copyright (c) 2015 ARM Limited
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,28 +14,28 @@
  * limitations under the License.
  */
 
-#ifndef ESP8266_INTERFACE_H
-#define ESP8266_INTERFACE_H
+#ifndef EMW3162_INTERFACE_H
+#define EMW3162_INTERFACE_H
 
 #include "NetworkSocketAPI/NetworkStack.h"
 #include "NetworkSocketAPI/WiFiInterface.h"
 #include "EMW3162.h"
 
 
-#define ESP8266_SOCKET_COUNT 5
+#define EMW3162_SOCKET_COUNT 5
 
 /** ESP8266Interface class
  *  Implementation of the NetworkStack for the ESP8266
  */
-class ESP8266Interface : public NetworkStack, public WiFiInterface
+class EMW3162Interface : public NetworkStack, public WiFiInterface
 {
 public:
-    /** ESP8266Interface lifetime
+    /** EMW3162Interface lifetime
      * @param tx        TX pin
      * @param rx        RX pin
      * @param debug     Enable debugging
      */
-    ESP8266Interface(PinName tx, PinName rx, bool debug = false);
+    EMW3162Interface(PinName tx, PinName rx, bool debug = false);
 
     /** Start the interface
      *
@@ -176,14 +176,14 @@
     }
     
 private:
-    ESP8266 _esp;
-    bool _ids[ESP8266_SOCKET_COUNT];
+    EMW3162 _esp;
+    bool _ids[EMW3162_SOCKET_COUNT];
 
     void event();
     struct {
         void (*callback)(void *);
         void *data;
-    } _cbs[ESP8266_SOCKET_COUNT];
+    } _cbs[EMW3162_SOCKET_COUNT];
 };
@@ -1,4 +1,4 @@
-/* ESP8266 implementation of NetworkInterfaceAPI
+/* EMW3162 implementation of NetworkInterfaceAPI
  * Copyright (c) 2015 ARM Limited
  *
@@ -14,28 +14,28 @@
 
-/** ESP8266Interface class
- *  Implementation of the NetworkStack for the ESP8266
+/** EMW3162Interface class
+ *  Implementation of the NetworkStack for the EMW3162
  */